==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/ExceptionFinder.h <==
// public class soot.dava.toolkits.base.finders.ExceptionFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6243b8c74c81b97 soot_dava_toolkits_base_finders_ExceptionFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_ExceptionFinder_H_
#define _JC_soot_dava_toolkits_base_finders_ExceptionFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$get__5fCatchBody$69f98fe4fc5fa632(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);
extern void _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$preprocess$e0343cb843422d2c(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method_info$get__5fCatchBody$69f98fe4fc5fa632;
extern _jc_method _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method_info$preprocess$e0343cb843422d2c;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *_jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$v$d6a8460396cd6900(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*get__5fCatchBody$69f98fe4fc5fa632)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);
	void	(*preprocess$e0343cb843422d2c)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods	soot_dava_toolkits_base_finders_ExceptionFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs {
    _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs	soot_dava_toolkits_base_finders_ExceptionFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs	soot_dava_toolkits_base_finders_ExceptionFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object {
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype _jc_soot_dava_toolkits_base_finders_ExceptionFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_ExceptionFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_ExceptionFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_ExceptionFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/ExceptionFinder.h <==
// public class soot.dava.toolkits.base.finders.ExceptionFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6243b8c74c81b97 soot_dava_toolkits_base_finders_ExceptionFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_ExceptionFinder_H_
#define _JC_soot_dava_toolkits_base_finders_ExceptionFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$get__5fCatchBody$69f98fe4fc5fa632(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$preprocess$e0343cb843422d2c(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method_info$get__5fCatchBody$69f98fe4fc5fa632;
extern _jc_method _jc_soot_dava_toolkits_base_finders_ExceptionFinder$method_info$preprocess$e0343cb843422d2c;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *_jc_soot_dava_toolkits_base_finders_ExceptionFinder$method$v$d6a8460396cd6900(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*get__5fCatchBody$69f98fe4fc5fa632)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;
	void	(*preprocess$e0343cb843422d2c)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vmethods	soot_dava_toolkits_base_finders_ExceptionFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs {
    _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_refs	soot_dava_toolkits_base_finders_ExceptionFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_ExceptionFinder$sub_nonrefs	soot_dava_toolkits_base_finders_ExceptionFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_ExceptionFinder$object {
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_ExceptionFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_ExceptionFinder$vtype _jc_soot_dava_toolkits_base_finders_ExceptionFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_ExceptionFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_ExceptionFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_ExceptionFinder_H_ */
